Stan Math Library: stan/math/fwd/scal/fun/is_inf.hpp Source File

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

is_inf.hpp
Go to the documentation of this file.
1 #ifndef STAN_MATH_FWD_SCAL_FUN_IS_INF_HPP
2 #define STAN_MATH_FWD_SCAL_FUN_IS_INF_HPP
3
4 #include <stan/math/fwd/core.hpp>
5 #include <stan/math/prim/scal/fun/is_inf.hpp>
6
7 namespace stan {
8
9 namespace math {
10
19 template <typename T>
20 inline
21 int
22 is_inf(const fvar<T>& x) {
23 using stan::math::is_inf;
24 return is_inf(x.val());
25 }
26
27 }
28 }
29
30 #endif
core.hpp
stan
Definition: log_sum_exp.hpp:8
is_inf.hpp
stan::math::is_inf
int is_inf(const fvar< T > &x)
Returns 1 if the input's value is infinite and 0 otherwise.
Definition: is_inf.hpp:22
stan::math::fvar::val
T val() const
Definition: fvar.hpp:17
stan::math::fvar
Definition: fvar.hpp:13

[ Stan Home Page ] © 2011–2016, Stan Development Team.